@@ -10,14 +10,14 @@ from ssb_altinn3_util.models.altinn3_cloud_event import Altinn3CloudEvent
 
 def add_altinn_event(db: Session, event: Altinn3CloudEvent) -> schema.AltinnEvent:
     db_event: schema.AltinnEvent = schema.AltinnEvent(**event.dict())
-    db_event.db_id = uuid.uuid4().hex[:6].lower()
+    db_event.db_id = uuid.uuid4().hex[:36].lower()
     db.add(db_event)
     db.flush()
     db.refresh(db_event)
     process = schema.AltinnEventProcess(
         event_id=db_event.db_id,
         received_at=datetime.utcnow(),
-        id=uuid.uuid4().hex[:6].lower(),
+        id=uuid.uuid4().hex[:36].lower(),
     )
     db.add(process)
     db.commit()
@@ -26,12 +26,12 @@ def add_altinn_event(db: Session, event: Altinn3CloudEvent) -> schema.AltinnEven
 
 
 def add_altinn_event_data(
-    db: Session, instance: str, data_url: str, event_db_id: int
+    db: Session, instance: str, data_url: str, event_db_id: str
 ) -> schema.AltinnEventData:
     event_data: schema.AltinnEventData = schema.AltinnEventData(
         event_id=event_db_id, instance=instance, data_base_url=data_url
     )
-    event_data.id = uuid.uuid4().hex[:6].lower()
+    event_data.id = uuid.uuid4().hex[:36].lower()
     db.add(event_data)
     db.commit()
     db.refresh(event_data)
@@ -40,7 +40,7 @@ def add_altinn_event_data(
 
 def update_event_data(
     db: Session,
-    event_db_id: int,
+    event_db_id: str,
     instance: Optional[str] = None,
     data_url: Optional[str] = None,
 ) -> schema.AltinnEventData:
@@ -60,7 +60,7 @@ def update_event_data(
 
 def update_progress(
     db: Session,
-    event_db_id: int,
+    event_db_id: str,
     data_fetched_at: Optional[datetime] = None,
     confirmed_altinn_at: Optional[datetime] = None,
     confirmed_ssb_at: Optional[datetime] = None,
@@ -98,7 +98,7 @@ def get_event_by_id(db: Session, event_id: str) -> schema.AltinnEvent:
     return event
 
 
-def get_event_by_db_id(db: Session, db_id: int) -> schema.AltinnEvent:
+def get_event_by_db_id(db: Session, db_id: str) -> schema.AltinnEvent:
     event: schema.AltinnEvent = (
         db.query(schema.AltinnEvent).filter(schema.AltinnEvent.db_id == db_id).first()
     )
@@ -118,7 +118,7 @@ def get_event_process_by_event_id(
 
 
 def get_event_process_by_event_db_id(
-    db: Session, event_db_id: int
+    db: Session, event_db_id: str
 ) -> schema.AltinnEventProcess:
     process: schema.AltinnEventProcess = (
         db.query(schema.AltinnEventProcess)
@@ -128,7 +128,7 @@ def get_event_process_by_event_db_id(
     return process
 
 
-def get_event_process_by_db_id(db: Session, db_id: int) -> schema.AltinnEventProcess:
+def get_event_process_by_db_id(db: Session, db_id: str) -> schema.AltinnEventProcess:
     process: schema.AltinnEventProcess = (
         db.query(schema.AltinnEventProcess)
         .filter(schema.AltinnEventProcess.id == db_id)
@@ -148,7 +148,7 @@ def get_event_data_by_event_id(db: Session, event_id: str) -> schema.AltinnEvent
 
 
 def get_event_data_by_event_db_id(
-    db: Session, event_db_id: int
+    db: Session, event_db_id: str
 ) -> schema.AltinnEventData:
     event_data: schema.AltinnEventData = (
         db.query(schema.AltinnEventData)
@@ -158,7 +158,7 @@ def get_event_data_by_event_db_id(
     return event_data
 
 
-def get_event_data_by_db_id(db: Session, db_id: int) -> schema.AltinnEventData:
+def get_event_data_by_db_id(db: Session, db_id: str) -> schema.AltinnEventData:
     event_data: schema.AltinnEventData = (
         db.query(schema.AltinnEventData)
         .filter(schema.AltinnEventData.id == db_id)
