@@ -7,7 +7,7 @@ from ssb_altinn3_util.database.altinn_mottak_db_adapter import AltinnMottakDbAda
 class AltinnEvent(AltinnMottakDbAdapter.Base):
     __tablename__ = "altinn_event"
 
-    db_id = Column("id", String, primary_key=True, length=36, index=True)
+    db_id = Column("id", String(length=36), primary_key=True, index=True)
     id = Column("event_id", String, unique=True, index=True)
     time = Column(DateTime)
     source = Column(String)
@@ -25,9 +25,9 @@ class AltinnEvent(AltinnMottakDbAdapter.Base):
 class AltinnEventProcess(AltinnMottakDbAdapter.Base):
     __tablename__ = "altinn_event_process"
 
-    id = Column("id", String, primary_key=True, length=36, index=True)
+    id = Column("id", String(length=36), primary_key=True, index=True)
     event_id = Column(
-        String, ForeignKey("altinn_event.id"), length=36, unique=True, index=True
+        String(length=36), ForeignKey("altinn_event.id"), unique=True, index=True
     )
     received_at = Column(DateTime)
     data_fetched_at = Column(DateTime)
@@ -40,9 +40,9 @@ class AltinnEventProcess(AltinnMottakDbAdapter.Base):
 class AltinnEventData(AltinnMottakDbAdapter.Base):
     __tablename__ = "altinn_event_data"
 
-    id = Column("id", String, primary_key=True, length=36, index=True)
+    id = Column("id", String(length=36), primary_key=True, index=True)
     event_id = Column(
-        String, ForeignKey("altinn_event.id"), length=36, unique=True, index=True
+        String(length=36), ForeignKey("altinn_event.id"), unique=True, index=True
     )
     instance = Column(String)
     data_base_url = Column(String)
